package com.inspect.metadata.montdata.service;

import com.inspect.metadata.montdata.domain.BasedataMontPatDevRunData;

import java.util.List;

public interface IBasedataMontPatDevRunDataService {
    BasedataMontPatDevRunData selectBasedataMontPatDevRunDataByMontPatDevRunDataId(Long dataId);

    List<BasedataMontPatDevRunData> selectBasedataMontPatDevRunDataList(BasedataMontPatDevRunData runData);

    int insertBasedataMontPatDevRunData(BasedataMontPatDevRunData runData);

    int updateBasedataMontPatDevRunData(BasedataMontPatDevRunData runData);

    int deleteBasedataMontPatDevRunDataByMontPatDevRunDataIds(Long[] dataIds);

    int deleteBasedataMontPatDevRunDataByMontPatDevRunDataId(Long dataId);
}
